OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
4. Pla d'acció
5. Informe
6. Grau d’emplenament 0%

# Descarregar i imprimir l'informe

Es recomana disposar d’una versió impresa i actualitzada de l’avaluació de riscos (informe) a la vostra empresa!

Informe

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Pla d'acció

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Resum de riscos

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Resum de mesures

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More